Learn R Programming

stdReg (version 3.4.1)

summary.parfrailty: Summarizes parfrailty fit

Description

This is a summary method for class "parfrailty".

Usage

# S3 method for parfrailty
summary(object, CI.type = "plain", CI.level = 0.95, 
  digits=max(3L, getOption("digits") - 3L), ...)

Arguments

object

an object of class "parfrailty".

CI.type

string, indicating the type of confidence intervals. Either "plain", which gives untransformed intervals, or "log", which gives log-transformed intervals.

CI.level

desired coverage probability of confidence intervals, in decimal form.

digits

the number of significant digits to use when printing..

…

not used.

See Also

parfrailty

Examples

Run this code
# NOT RUN {
##See documentation for frailty

# }

Run the code above in your browser using DataLab